@@ -1,10 +1,5 @@
-# from trackable.models import TrackableData, TrackableTimeSeriesData, TrackableError
-# from trackable.sites import TrackableRegistry, site
 
 
-class TrackableError(Exception):
-    pass
-
 def autodiscover():
     """
     Auto-discover INSTALLED_APPS trackabledata.py modules and fail silently when
