@@ -1,8 +1,8 @@
 from django.core.management.base import BaseCommand, CommandError
 from django.db.models.loading import get_model
 
-from trackable.messaging import process_messages
 from trackable.sites import site, NotRegistered
+from trackable.message import connection
 
 
 class Command(BaseCommand):
@@ -23,7 +23,8 @@ class Command(BaseCommand):
                 site.get_parent( model_cls )
             except NotRegistered, e:
                 raise CommandError( str(e) )
-            process_messages(model_cls=model_cls)
+            cnt = connection.process_messages(model_cls=model_cls)
         if not len(trackable_model_specs):
             print "Processing messages for all trackable models"
-            process_messages()
+            cnt = connection.process_messages()
+        print "Processed %d" % (cnt)
